# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class ChartSeriesGroup(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'gap_width': 'int',
        'gap_depth': 'int',
        'first_slice_angle': 'int',
        'is_color_varied': 'bool',
        'has_series_lines': 'bool',
        'overlap': 'int',
        'second_pie_size': 'int',
        'pie_split_position': 'float',
        'pie_split_by': 'str',
        'doughnut_hole_size': 'int',
        'bubble_size_scale': 'int',
        'hi_low_lines_format': 'ChartLinesFormat',
        'bubble_size_representation': 'str'
    }

    attribute_map = {
        'type': 'type',
        'gap_width': 'gapWidth',
        'gap_depth': 'gapDepth',
        'first_slice_angle': 'firstSliceAngle',
        'is_color_varied': 'isColorVaried',
        'has_series_lines': 'hasSeriesLines',
        'overlap': 'overlap',
        'second_pie_size': 'secondPieSize',
        'pie_split_position': 'pieSplitPosition',
        'pie_split_by': 'pieSplitBy',
        'doughnut_hole_size': 'doughnutHoleSize',
        'bubble_size_scale': 'bubbleSizeScale',
        'hi_low_lines_format': 'hiLowLinesFormat',
        'bubble_size_representation': 'bubbleSizeRepresentation'
    }

    type_determiners = {
    }

    def __init__(self, type=None, gap_width=None, gap_depth=None, first_slice_angle=None, is_color_varied=None, has_series_lines=None, overlap=None, second_pie_size=None, pie_split_position=None, pie_split_by=None, doughnut_hole_size=None, bubble_size_scale=None, hi_low_lines_format=None, bubble_size_representation=None):  # noqa: E501
        """ChartSeriesGroup - a model defined in Swagger"""  # noqa: E501

        self._type = None
        self._gap_width = None
        self._gap_depth = None
        self._first_slice_angle = None
        self._is_color_varied = None
        self._has_series_lines = None
        self._overlap = None
        self._second_pie_size = None
        self._pie_split_position = None
        self._pie_split_by = None
        self._doughnut_hole_size = None
        self._bubble_size_scale = None
        self._hi_low_lines_format = None
        self._bubble_size_representation = None

        if type is not None:
            self.type = type
        if gap_width is not None:
            self.gap_width = gap_width
        if gap_depth is not None:
            self.gap_depth = gap_depth
        if first_slice_angle is not None:
            self.first_slice_angle = first_slice_angle
        if is_color_varied is not None:
            self.is_color_varied = is_color_varied
        if has_series_lines is not None:
            self.has_series_lines = has_series_lines
        if overlap is not None:
            self.overlap = overlap
        if second_pie_size is not None:
            self.second_pie_size = second_pie_size
        if pie_split_position is not None:
            self.pie_split_position = pie_split_position
        if pie_split_by is not None:
            self.pie_split_by = pie_split_by
        if doughnut_hole_size is not None:
            self.doughnut_hole_size = doughnut_hole_size
        if bubble_size_scale is not None:
            self.bubble_size_scale = bubble_size_scale
        if hi_low_lines_format is not None:
            self.hi_low_lines_format = hi_low_lines_format
        if bubble_size_representation is not None:
            self.bubble_size_representation = bubble_size_representation

    @property
    def type(self):
        """Gets the type of this ChartSeriesGroup.  # noqa: E501

        Returns a type of this series group.  # noqa: E501

        :return: The type of this ChartSeriesGroup.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ChartSeriesGroup.

        Returns a type of this series group.  # noqa: E501

        :param type: The type of this ChartSeriesGroup.  # noqa: E501
        :type: str
        """
        if type is not None:
            allowed_values = ["BarOfPieChart", "PieOfPieChart", "DoughnutChart", "PieChart", "AreaChartArea", "AreaChartPercentsStackedArea", "AreaChartStackedArea", "BarChartHorizClustered", "BarChartHorizStacked", "BarChartHorizPercentsStacked", "BarChartVertClustered", "BarChartVertStacked", "BarChartVertPercentsStacked", "LineChartLine", "LineChartStackedLine", "LineChartPercentsStackedLine", "RadarChart", "FilledRadarChart", "StockHighLowClose", "StockOpenHighLowClose", "StockVolumeHighLowClose", "StockVolumeOpenHighLowClose", "ScatterStraightMarker", "ScatterSmoothMarker", "AreaChartArea3D", "AreaChartStackedArea3D", "AreaChartPercentsStackedArea3D", "Line3DChart", "Pie3DChart", "Bar3DChartVert", "Bar3DChartVertClustered", "Bar3DChartVertPercentsStackedColumn3D", "Bar3DChartVertPercentsStackedCone", "Bar3DChartVertPercentsStackedCylinder", "Bar3DChartVertPercentsStackedPyramid", "Bar3DChartVertStackedColumn3D", "Bar3DChartVertStackedCone", "Bar3DChartVertStackedCylinder", "Bar3DChartVertStackedPyramid", "Bar3DChartHorizClustered", "Bar3DChartHorizStackedBar3D", "Bar3DChartHorizStackedCone", "Bar3DChartHorizStackedCylinder", "Bar3DChartHorizStackedPyramid", "Bar3DChartHorizPercentsStackedBar3D", "Bar3DChartHorizPercentsStackedCone", "Bar3DChartHorizPercentsStackedCylinder", "Bar3DChartHorizPercentsStackedPyramid", "SurfaceChartContour", "SurfaceChartWireframeContour", "SurfaceChartSurface3D", "SurfaceChartWireframeSurface3D", "BubbleChart", "HistogramChart", "ParetoLineChart", "BoxAndWhiskerChart", "WaterfallChart", "FunnelChart", "TreemapChart", "MapChart", "SunburstChart"]  # noqa: E501
            if type.isdigit():
                int_type = int(type)
                if int_type < 0 or int_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                        .format(type, allowed_values)
                    )
                self._type = allowed_values[int_type]
                return
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                    .format(type, allowed_values)
                )
        self._type = type

    @property
    def gap_width(self):
        """Gets the gap_width of this ChartSeriesGroup.  # noqa: E501

        Specifies the space between bar or column clusters, as a percentage of the bar or column width.  # noqa: E501

        :return: The gap_width of this ChartSeriesGroup.  # noqa: E501
        :rtype: int
        """
        return self._gap_width

    @gap_width.setter
    def gap_width(self, gap_width):
        """Sets the gap_width of this ChartSeriesGroup.

        Specifies the space between bar or column clusters, as a percentage of the bar or column width.  # noqa: E501

        :param gap_width: The gap_width of this ChartSeriesGroup.  # noqa: E501
        :type: int
        """
        self._gap_width = gap_width

    @property
    def gap_depth(self):
        """Gets the gap_depth of this ChartSeriesGroup.  # noqa: E501

        Returns or sets the distance, as a percentage of the marker width, between the data series in a 3D chart.  # noqa: E501

        :return: The gap_depth of this ChartSeriesGroup.  # noqa: E501
        :rtype: int
        """
        return self._gap_depth

    @gap_depth.setter
    def gap_depth(self, gap_depth):
        """Sets the gap_depth of this ChartSeriesGroup.

        Returns or sets the distance, as a percentage of the marker width, between the data series in a 3D chart.  # noqa: E501

        :param gap_depth: The gap_depth of this ChartSeriesGroup.  # noqa: E501
        :type: int
        """
        self._gap_depth = gap_depth

    @property
    def first_slice_angle(self):
        """Gets the first_slice_angle of this ChartSeriesGroup.  # noqa: E501

        Gets or sets the angle of the first pie or doughnut chart slice,  in degrees (clockwise from up, from 0 to 360 degrees).  # noqa: E501

        :return: The first_slice_angle of this ChartSeriesGroup.  # noqa: E501
        :rtype: int
        """
        return self._first_slice_angle

    @first_slice_angle.setter
    def first_slice_angle(self, first_slice_angle):
        """Sets the first_slice_angle of this ChartSeriesGroup.

        Gets or sets the angle of the first pie or doughnut chart slice,  in degrees (clockwise from up, from 0 to 360 degrees).  # noqa: E501

        :param first_slice_angle: The first_slice_angle of this ChartSeriesGroup.  # noqa: E501
        :type: int
        """
        self._first_slice_angle = first_slice_angle

    @property
    def is_color_varied(self):
        """Gets the is_color_varied of this ChartSeriesGroup.  # noqa: E501

        Specifies that each data marker in the series has a different color.  # noqa: E501

        :return: The is_color_varied of this ChartSeriesGroup.  # noqa: E501
        :rtype: bool
        """
        return self._is_color_varied

    @is_color_varied.setter
    def is_color_varied(self, is_color_varied):
        """Sets the is_color_varied of this ChartSeriesGroup.

        Specifies that each data marker in the series has a different color.  # noqa: E501

        :param is_color_varied: The is_color_varied of this ChartSeriesGroup.  # noqa: E501
        :type: bool
        """
        self._is_color_varied = is_color_varied

    @property
    def has_series_lines(self):
        """Gets the has_series_lines of this ChartSeriesGroup.  # noqa: E501

        True if chart has series lines. Applied to stacked bar and OfPie charts.  # noqa: E501

        :return: The has_series_lines of this ChartSeriesGroup.  # noqa: E501
        :rtype: bool
        """
        return self._has_series_lines

    @has_series_lines.setter
    def has_series_lines(self, has_series_lines):
        """Sets the has_series_lines of this ChartSeriesGroup.

        True if chart has series lines. Applied to stacked bar and OfPie charts.  # noqa: E501

        :param has_series_lines: The has_series_lines of this ChartSeriesGroup.  # noqa: E501
        :type: bool
        """
        self._has_series_lines = has_series_lines

    @property
    def overlap(self):
        """Gets the overlap of this ChartSeriesGroup.  # noqa: E501

        Specifies how much bars and columns shall overlap on 2-D charts (from -100 to 100).  # noqa: E501

        :return: The overlap of this ChartSeriesGroup.  # noqa: E501
        :rtype: int
        """
        return self._overlap

    @overlap.setter
    def overlap(self, overlap):
        """Sets the overlap of this ChartSeriesGroup.

        Specifies how much bars and columns shall overlap on 2-D charts (from -100 to 100).  # noqa: E501

        :param overlap: The overlap of this ChartSeriesGroup.  # noqa: E501
        :type: int
        """
        self._overlap = overlap

    @property
    def second_pie_size(self):
        """Gets the second_pie_size of this ChartSeriesGroup.  # noqa: E501

        Specifies the size of the second pie or bar of a pie-of-pie chart or  a bar-of-pie chart, as a percentage of the size of the first pie (can  be between 5 and 200 percents).  # noqa: E501

        :return: The second_pie_size of this ChartSeriesGroup.  # noqa: E501
        :rtype: int
        """
        return self._second_pie_size

    @second_pie_size.setter
    def second_pie_size(self, second_pie_size):
        """Sets the second_pie_size of this ChartSeriesGroup.

        Specifies the size of the second pie or bar of a pie-of-pie chart or  a bar-of-pie chart, as a percentage of the size of the first pie (can  be between 5 and 200 percents).  # noqa: E501

        :param second_pie_size: The second_pie_size of this ChartSeriesGroup.  # noqa: E501
        :type: int
        """
        self._second_pie_size = second_pie_size

    @property
    def pie_split_position(self):
        """Gets the pie_split_position of this ChartSeriesGroup.  # noqa: E501

        Specifies a value that shall be used to determine which data points  are in the second pie or bar on a pie-of-pie or bar-of-pie chart.  Is used together with PieSplitBy property.  # noqa: E501

        :return: The pie_split_position of this ChartSeriesGroup.  # noqa: E501
        :rtype: float
        """
        return self._pie_split_position

    @pie_split_position.setter
    def pie_split_position(self, pie_split_position):
        """Sets the pie_split_position of this ChartSeriesGroup.

        Specifies a value that shall be used to determine which data points  are in the second pie or bar on a pie-of-pie or bar-of-pie chart.  Is used together with PieSplitBy property.  # noqa: E501

        :param pie_split_position: The pie_split_position of this ChartSeriesGroup.  # noqa: E501
        :type: float
        """
        self._pie_split_position = pie_split_position

    @property
    def pie_split_by(self):
        """Gets the pie_split_by of this ChartSeriesGroup.  # noqa: E501

        Specifies how to determine which data points are in the second pie or bar  on a pie-of-pie or bar-of-pie chart.  # noqa: E501

        :return: The pie_split_by of this ChartSeriesGroup.  # noqa: E501
        :rtype: str
        """
        return self._pie_split_by

    @pie_split_by.setter
    def pie_split_by(self, pie_split_by):
        """Sets the pie_split_by of this ChartSeriesGroup.

        Specifies how to determine which data points are in the second pie or bar  on a pie-of-pie or bar-of-pie chart.  # noqa: E501

        :param pie_split_by: The pie_split_by of this ChartSeriesGroup.  # noqa: E501
        :type: str
        """
        if pie_split_by is not None:
            allowed_values = ["Default", "Custom", "ByPercentage", "ByPos", "ByValue"]  # noqa: E501
            if pie_split_by.isdigit():
                int_pie_split_by = int(pie_split_by)
                if int_pie_split_by < 0 or int_pie_split_by >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `pie_split_by` ({0}), must be one of {1}"  # noqa: E501
                        .format(pie_split_by, allowed_values)
                    )
                self._pie_split_by = allowed_values[int_pie_split_by]
                return
            if pie_split_by not in allowed_values:
                raise ValueError(
                    "Invalid value for `pie_split_by` ({0}), must be one of {1}"  # noqa: E501
                    .format(pie_split_by, allowed_values)
                )
        self._pie_split_by = pie_split_by

    @property
    def doughnut_hole_size(self):
        """Gets the doughnut_hole_size of this ChartSeriesGroup.  # noqa: E501

        Specifies the size of the hole in a doughnut chart (can be between 10 and 90 percents  of the size of the plot area.).  # noqa: E501

        :return: The doughnut_hole_size of this ChartSeriesGroup.  # noqa: E501
        :rtype: int
        """
        return self._doughnut_hole_size

    @doughnut_hole_size.setter
    def doughnut_hole_size(self, doughnut_hole_size):
        """Sets the doughnut_hole_size of this ChartSeriesGroup.

        Specifies the size of the hole in a doughnut chart (can be between 10 and 90 percents  of the size of the plot area.).  # noqa: E501

        :param doughnut_hole_size: The doughnut_hole_size of this ChartSeriesGroup.  # noqa: E501
        :type: int
        """
        self._doughnut_hole_size = doughnut_hole_size

    @property
    def bubble_size_scale(self):
        """Gets the bubble_size_scale of this ChartSeriesGroup.  # noqa: E501

        Specifies the scale factor for the bubble chart (can be  between 0 and 300 percents of the default size). Read/write Int32.  # noqa: E501

        :return: The bubble_size_scale of this ChartSeriesGroup.  # noqa: E501
        :rtype: int
        """
        return self._bubble_size_scale

    @bubble_size_scale.setter
    def bubble_size_scale(self, bubble_size_scale):
        """Sets the bubble_size_scale of this ChartSeriesGroup.

        Specifies the scale factor for the bubble chart (can be  between 0 and 300 percents of the default size). Read/write Int32.  # noqa: E501

        :param bubble_size_scale: The bubble_size_scale of this ChartSeriesGroup.  # noqa: E501
        :type: int
        """
        self._bubble_size_scale = bubble_size_scale

    @property
    def hi_low_lines_format(self):
        """Gets the hi_low_lines_format of this ChartSeriesGroup.  # noqa: E501

        Specifies HiLowLines format.  HiLowLines applied with HiLowClose, OpenHiLowClose, VolumeHiLowClose and VolumeOpenHiLowClose chart types.  # noqa: E501

        :return: The hi_low_lines_format of this ChartSeriesGroup.  # noqa: E501
        :rtype: ChartLinesFormat
        """
        return self._hi_low_lines_format

    @hi_low_lines_format.setter
    def hi_low_lines_format(self, hi_low_lines_format):
        """Sets the hi_low_lines_format of this ChartSeriesGroup.

        Specifies HiLowLines format.  HiLowLines applied with HiLowClose, OpenHiLowClose, VolumeHiLowClose and VolumeOpenHiLowClose chart types.  # noqa: E501

        :param hi_low_lines_format: The hi_low_lines_format of this ChartSeriesGroup.  # noqa: E501
        :type: ChartLinesFormat
        """
        self._hi_low_lines_format = hi_low_lines_format

    @property
    def bubble_size_representation(self):
        """Gets the bubble_size_representation of this ChartSeriesGroup.  # noqa: E501

        Specifies how the bubble size values are represented on the bubble chart. Read/write BubbleSizeRepresentationType.  # noqa: E501

        :return: The bubble_size_representation of this ChartSeriesGroup.  # noqa: E501
        :rtype: str
        """
        return self._bubble_size_representation

    @bubble_size_representation.setter
    def bubble_size_representation(self, bubble_size_representation):
        """Sets the bubble_size_representation of this ChartSeriesGroup.

        Specifies how the bubble size values are represented on the bubble chart. Read/write BubbleSizeRepresentationType.  # noqa: E501

        :param bubble_size_representation: The bubble_size_representation of this ChartSeriesGroup.  # noqa: E501
        :type: str
        """
        if bubble_size_representation is not None:
            allowed_values = ["Area", "Width"]  # noqa: E501
            if bubble_size_representation.isdigit():
                int_bubble_size_representation = int(bubble_size_representation)
                if int_bubble_size_representation < 0 or int_bubble_size_representation >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `bubble_size_representation` ({0}), must be one of {1}"  # noqa: E501
                        .format(bubble_size_representation, allowed_values)
                    )
                self._bubble_size_representation = allowed_values[int_bubble_size_representation]
                return
            if bubble_size_representation not in allowed_values:
                raise ValueError(
                    "Invalid value for `bubble_size_representation` ({0}), must be one of {1}"  # noqa: E501
                    .format(bubble_size_representation, allowed_values)
                )
        self._bubble_size_representation = bubble_size_representation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChartSeriesGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.math_element import MathElement

class DelimiterElement(MathElement):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'arguments': 'list[MathElement]',
        'beginning_character': 'str',
        'separator_character': 'str',
        'ending_character': 'str',
        'grow_to_match_operand_height': 'bool',
        'delimiter_shape': 'str'
    }

    attribute_map = {
        'type': 'type',
        'arguments': 'arguments',
        'beginning_character': 'beginningCharacter',
        'separator_character': 'separatorCharacter',
        'ending_character': 'endingCharacter',
        'grow_to_match_operand_height': 'growToMatchOperandHeight',
        'delimiter_shape': 'delimiterShape'
    }

    type_determiners = {
        'type': 'Delimiter',
    }

    def __init__(self, type='Delimiter', arguments=None, beginning_character=None, separator_character=None, ending_character=None, grow_to_match_operand_height=None, delimiter_shape=None):  # noqa: E501
        """DelimiterElement - a model defined in Swagger"""  # noqa: E501
        super(DelimiterElement, self).__init__(type)

        self._arguments = None
        self._beginning_character = None
        self._separator_character = None
        self._ending_character = None
        self._grow_to_match_operand_height = None
        self._delimiter_shape = None
        self.type = 'Delimiter'

        if arguments is not None:
            self.arguments = arguments
        if beginning_character is not None:
            self.beginning_character = beginning_character
        if separator_character is not None:
            self.separator_character = separator_character
        if ending_character is not None:
            self.ending_character = ending_character
        if grow_to_match_operand_height is not None:
            self.grow_to_match_operand_height = grow_to_match_operand_height
        if delimiter_shape is not None:
            self.delimiter_shape = delimiter_shape

    @property
    def arguments(self):
        """Gets the arguments of this DelimiterElement.  # noqa: E501

        Arguments  # noqa: E501

        :return: The arguments of this DelimiterElement.  # noqa: E501
        :rtype: list[MathElement]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this DelimiterElement.

        Arguments  # noqa: E501

        :param arguments: The arguments of this DelimiterElement.  # noqa: E501
        :type: list[MathElement]
        """
        self._arguments = arguments

    @property
    def beginning_character(self):
        """Gets the beginning_character of this DelimiterElement.  # noqa: E501

        Beginning character  # noqa: E501

        :return: The beginning_character of this DelimiterElement.  # noqa: E501
        :rtype: str
        """
        return self._beginning_character

    @beginning_character.setter
    def beginning_character(self, beginning_character):
        """Sets the beginning_character of this DelimiterElement.

        Beginning character  # noqa: E501

        :param beginning_character: The beginning_character of this DelimiterElement.  # noqa: E501
        :type: str
        """
        self._beginning_character = beginning_character

    @property
    def separator_character(self):
        """Gets the separator_character of this DelimiterElement.  # noqa: E501

        Separator character  # noqa: E501

        :return: The separator_character of this DelimiterElement.  # noqa: E501
        :rtype: str
        """
        return self._separator_character

    @separator_character.setter
    def separator_character(self, separator_character):
        """Sets the separator_character of this DelimiterElement.

        Separator character  # noqa: E501

        :param separator_character: The separator_character of this DelimiterElement.  # noqa: E501
        :type: str
        """
        self._separator_character = separator_character

    @property
    def ending_character(self):
        """Gets the ending_character of this DelimiterElement.  # noqa: E501

        Ending character  # noqa: E501

        :return: The ending_character of this DelimiterElement.  # noqa: E501
        :rtype: str
        """
        return self._ending_character

    @ending_character.setter
    def ending_character(self, ending_character):
        """Sets the ending_character of this DelimiterElement.

        Ending character  # noqa: E501

        :param ending_character: The ending_character of this DelimiterElement.  # noqa: E501
        :type: str
        """
        self._ending_character = ending_character

    @property
    def grow_to_match_operand_height(self):
        """Gets the grow_to_match_operand_height of this DelimiterElement.  # noqa: E501

        Grow to match operand height  # noqa: E501

        :return: The grow_to_match_operand_height of this DelimiterElement.  # noqa: E501
        :rtype: bool
        """
        return self._grow_to_match_operand_height

    @grow_to_match_operand_height.setter
    def grow_to_match_operand_height(self, grow_to_match_operand_height):
        """Sets the grow_to_match_operand_height of this DelimiterElement.

        Grow to match operand height  # noqa: E501

        :param grow_to_match_operand_height: The grow_to_match_operand_height of this DelimiterElement.  # noqa: E501
        :type: bool
        """
        self._grow_to_match_operand_height = grow_to_match_operand_height

    @property
    def delimiter_shape(self):
        """Gets the delimiter_shape of this DelimiterElement.  # noqa: E501

        Delimiter shape  # noqa: E501

        :return: The delimiter_shape of this DelimiterElement.  # noqa: E501
        :rtype: str
        """
        return self._delimiter_shape

    @delimiter_shape.setter
    def delimiter_shape(self, delimiter_shape):
        """Sets the delimiter_shape of this DelimiterElement.

        Delimiter shape  # noqa: E501

        :param delimiter_shape: The delimiter_shape of this DelimiterElement.  # noqa: E501
        :type: str
        """
        if delimiter_shape is not None:
            allowed_values = ["Centered", "Match"]  # noqa: E501
            if delimiter_shape.isdigit():
                int_delimiter_shape = int(delimiter_shape)
                if int_delimiter_shape < 0 or int_delimiter_shape >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `delimiter_shape` ({0}), must be one of {1}"  # noqa: E501
                        .format(delimiter_shape, allowed_values)
                    )
                self._delimiter_shape = allowed_values[int_delimiter_shape]
                return
            if delimiter_shape not in allowed_values:
                raise ValueError(
                    "Invalid value for `delimiter_shape` ({0}), must be one of {1}"  # noqa: E501
                    .format(delimiter_shape, allowed_values)
                )
        self._delimiter_shape = delimiter_shape

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DelimiterElement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.resource_base import ResourceBase

class ShapeBase(ResourceBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'name': 'str',
        'width': 'float',
        'height': 'float',
        'alternative_text': 'str',
        'alternative_text_title': 'str',
        'hidden': 'bool',
        'x': 'float',
        'y': 'float',
        'z_order_position': 'int',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'three_d_format': 'ThreeDFormat',
        'line_format': 'LineFormat',
        'hyperlink_click': 'Hyperlink',
        'hyperlink_mouse_over': 'Hyperlink',
        'type': 'str'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'name': 'name',
        'width': 'width',
        'height': 'height',
        'alternative_text': 'alternativeText',
        'alternative_text_title': 'alternativeTextTitle',
        'hidden': 'hidden',
        'x': 'x',
        'y': 'y',
        'z_order_position': 'zOrderPosition',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'three_d_format': 'threeDFormat',
        'line_format': 'lineFormat',
        'hyperlink_click': 'hyperlinkClick',
        'hyperlink_mouse_over': 'hyperlinkMouseOver',
        'type': 'type'
    }

    type_determiners = {
    }

    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, fill_format=None, effect_format=None, three_d_format=None, line_format=None, hyperlink_click=None, hyperlink_mouse_over=None, type=None):  # noqa: E501
        """ShapeBase - a model defined in Swagger"""  # noqa: E501
        super(ShapeBase, self).__init__(self_uri, alternate_links)

        self._name = None
        self._width = None
        self._height = None
        self._alternative_text = None
        self._alternative_text_title = None
        self._hidden = None
        self._x = None
        self._y = None
        self._z_order_position = None
        self._fill_format = None
        self._effect_format = None
        self._three_d_format = None
        self._line_format = None
        self._hyperlink_click = None
        self._hyperlink_mouse_over = None
        self._type = None

        if name is not None:
            self.name = name
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if alternative_text is not None:
            self.alternative_text = alternative_text
        if alternative_text_title is not None:
            self.alternative_text_title = alternative_text_title
        if hidden is not None:
            self.hidden = hidden
        if x is not None:
            self.x = x
        if y is not None:
            self.y = y
        self.z_order_position = z_order_position
        if fill_format is not None:
            self.fill_format = fill_format
        if effect_format is not None:
            self.effect_format = effect_format
        if three_d_format is not None:
            self.three_d_format = three_d_format
        if line_format is not None:
            self.line_format = line_format
        if hyperlink_click is not None:
            self.hyperlink_click = hyperlink_click
        if hyperlink_mouse_over is not None:
            self.hyperlink_mouse_over = hyperlink_mouse_over
        if type is not None:
            self.type = type

    @property
    def name(self):
        """Gets the name of this ShapeBase.  # noqa: E501

        Gets or sets the name.  # noqa: E501

        :return: The name of this ShapeBase.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ShapeBase.

        Gets or sets the name.  # noqa: E501

        :param name: The name of this ShapeBase.  # noqa: E501
        :type: str
        """
        self._name = name

    @property
    def width(self):
        """Gets the width of this ShapeBase.  # noqa: E501

        Gets or sets the width.  # noqa: E501

        :return: The width of this ShapeBase.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this ShapeBase.

        Gets or sets the width.  # noqa: E501

        :param width: The width of this ShapeBase.  # noqa: E501
        :type: float
        """
        self._width = width

    @property
    def height(self):
        """Gets the height of this ShapeBase.  # noqa: E501

        Gets or sets the height.  # noqa: E501

        :return: The height of this ShapeBase.  # noqa: E501
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this ShapeBase.

        Gets or sets the height.  # noqa: E501

        :param height: The height of this ShapeBase.  # noqa: E501
        :type: float
        """
        self._height = height

    @property
    def alternative_text(self):
        """Gets the alternative_text of this ShapeBase.  # noqa: E501

        Gets or sets the alternative text.  # noqa: E501

        :return: The alternative_text of this ShapeBase.  # noqa: E501
        :rtype: str
        """
        return self._alternative_text

    @alternative_text.setter
    def alternative_text(self, alternative_text):
        """Sets the alternative_text of this ShapeBase.

        Gets or sets the alternative text.  # noqa: E501

        :param alternative_text: The alternative_text of this ShapeBase.  # noqa: E501
        :type: str
        """
        self._alternative_text = alternative_text

    @property
    def alternative_text_title(self):
        """Gets the alternative_text_title of this ShapeBase.  # noqa: E501

        The title of alternative text associated with the shape.  # noqa: E501

        :return: The alternative_text_title of this ShapeBase.  # noqa: E501
        :rtype: str
        """
        return self._alternative_text_title

    @alternative_text_title.setter
    def alternative_text_title(self, alternative_text_title):
        """Sets the alternative_text_title of this ShapeBase.

        The title of alternative text associated with the shape.  # noqa: E501

        :param alternative_text_title: The alternative_text_title of this ShapeBase.  # noqa: E501
        :type: str
        """
        self._alternative_text_title = alternative_text_title

    @property
    def hidden(self):
        """Gets the hidden of this ShapeBase.  # noqa: E501

        Gets or sets a value indicating whether this ShapeBase is hidden.  # noqa: E501

        :return: The hidden of this ShapeBase.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this ShapeBase.

        Gets or sets a value indicating whether this ShapeBase is hidden.  # noqa: E501

        :param hidden: The hidden of this ShapeBase.  # noqa: E501
        :type: bool
        """
        self._hidden = hidden

    @property
    def x(self):
        """Gets the x of this ShapeBase.  # noqa: E501

        Gets or sets the X  # noqa: E501

        :return: The x of this ShapeBase.  # noqa: E501
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this ShapeBase.

        Gets or sets the X  # noqa: E501

        :param x: The x of this ShapeBase.  # noqa: E501
        :type: float
        """
        self._x = x

    @property
    def y(self):
        """Gets the y of this ShapeBase.  # noqa: E501

        Gets or sets the Y.  # noqa: E501

        :return: The y of this ShapeBase.  # noqa: E501
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this ShapeBase.

        Gets or sets the Y.  # noqa: E501

        :param y: The y of this ShapeBase.  # noqa: E501
        :type: float
        """
        self._y = y

    @property
    def z_order_position(self):
        """Gets the z_order_position of this ShapeBase.  # noqa: E501

        Gets z-order position of shape  # noqa: E501

        :return: The z_order_position of this ShapeBase.  # noqa: E501
        :rtype: int
        """
        return self._z_order_position

    @z_order_position.setter
    def z_order_position(self, z_order_position):
        """Sets the z_order_position of this ShapeBase.

        Gets z-order position of shape  # noqa: E501

        :param z_order_position: The z_order_position of this ShapeBase.  # noqa: E501
        :type: int
        """
        self._z_order_position = z_order_position

    @property
    def fill_format(self):
        """Gets the fill_format of this ShapeBase.  # noqa: E501

        Gets or sets the fill format.  # noqa: E501

        :return: The fill_format of this ShapeBase.  # noqa: E501
        :rtype: FillFormat
        """
        return self._fill_format

    @fill_format.setter
    def fill_format(self, fill_format):
        """Sets the fill_format of this ShapeBase.

        Gets or sets the fill format.  # noqa: E501

        :param fill_format: The fill_format of this ShapeBase.  # noqa: E501
        :type: FillFormat
        """
        self._fill_format = fill_format

    @property
    def effect_format(self):
        """Gets the effect_format of this ShapeBase.  # noqa: E501

        Gets or sets the effect format.  # noqa: E501

        :return: The effect_format of this ShapeBase.  # noqa: E501
        :rtype: EffectFormat
        """
        return self._effect_format

    @effect_format.setter
    def effect_format(self, effect_format):
        """Sets the effect_format of this ShapeBase.

        Gets or sets the effect format.  # noqa: E501

        :param effect_format: The effect_format of this ShapeBase.  # noqa: E501
        :type: EffectFormat
        """
        self._effect_format = effect_format

    @property
    def three_d_format(self):
        """Gets the three_d_format of this ShapeBase.  # noqa: E501

        Gets or sets the 3D format  # noqa: E501

        :return: The three_d_format of this ShapeBase.  # noqa: E501
        :rtype: ThreeDFormat
        """
        return self._three_d_format

    @three_d_format.setter
    def three_d_format(self, three_d_format):
        """Sets the three_d_format of this ShapeBase.

        Gets or sets the 3D format  # noqa: E501

        :param three_d_format: The three_d_format of this ShapeBase.  # noqa: E501
        :type: ThreeDFormat
        """
        self._three_d_format = three_d_format

    @property
    def line_format(self):
        """Gets the line_format of this ShapeBase.  # noqa: E501

        Gets or sets the line format.  # noqa: E501

        :return: The line_format of this ShapeBase.  # noqa: E501
        :rtype: LineFormat
        """
        return self._line_format

    @line_format.setter
    def line_format(self, line_format):
        """Sets the line_format of this ShapeBase.

        Gets or sets the line format.  # noqa: E501

        :param line_format: The line_format of this ShapeBase.  # noqa: E501
        :type: LineFormat
        """
        self._line_format = line_format

    @property
    def hyperlink_click(self):
        """Gets the hyperlink_click of this ShapeBase.  # noqa: E501

        Hyperlink defined for mouse click.  # noqa: E501

        :return: The hyperlink_click of this ShapeBase.  # noqa: E501
        :rtype: Hyperlink
        """
        return self._hyperlink_click

    @hyperlink_click.setter
    def hyperlink_click(self, hyperlink_click):
        """Sets the hyperlink_click of this ShapeBase.

        Hyperlink defined for mouse click.  # noqa: E501

        :param hyperlink_click: The hyperlink_click of this ShapeBase.  # noqa: E501
        :type: Hyperlink
        """
        self._hyperlink_click = hyperlink_click

    @property
    def hyperlink_mouse_over(self):
        """Gets the hyperlink_mouse_over of this ShapeBase.  # noqa: E501

        Hyperlink defined for mouse over.  # noqa: E501

        :return: The hyperlink_mouse_over of this ShapeBase.  # noqa: E501
        :rtype: Hyperlink
        """
        return self._hyperlink_mouse_over

    @hyperlink_mouse_over.setter
    def hyperlink_mouse_over(self, hyperlink_mouse_over):
        """Sets the hyperlink_mouse_over of this ShapeBase.

        Hyperlink defined for mouse over.  # noqa: E501

        :param hyperlink_mouse_over: The hyperlink_mouse_over of this ShapeBase.  # noqa: E501
        :type: Hyperlink
        """
        self._hyperlink_mouse_over = hyperlink_mouse_over

    @property
    def type(self):
        """Gets the type of this ShapeBase.  # noqa: E501


        :return: The type of this ShapeBase.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShapeBase.


        :param type: The type of this ShapeBase.  # noqa: E501
        :type: str
        """
        if type is not None:
            allowed_values = ["Shape", "Chart", "Table", "PictureFrame", "VideoFrame", "AudioFrame", "SmartArt", "OleObjectFrame", "GroupShape", "GraphicalObject", "Connector", "SmartArtShape", "ZoomFrame", "SectionZoomFrame", "SummaryZoomFrame", "SummaryZoomSection"]  # noqa: E501
            if type.isdigit():
                int_type = int(type)
                if int_type < 0 or int_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                        .format(type, allowed_values)
                    )
                self._type = allowed_values[int_type]
                return
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                    .format(type, allowed_values)
                )
        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShapeBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.resource_base import ResourceBase

class HeaderFooter(ResourceBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'is_date_time_visible': 'bool',
        'date_time_text': 'str',
        'is_footer_visible': 'bool',
        'footer_text': 'str',
        'is_slide_number_visible': 'bool'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'is_date_time_visible': 'isDateTimeVisible',
        'date_time_text': 'dateTimeText',
        'is_footer_visible': 'isFooterVisible',
        'footer_text': 'footerText',
        'is_slide_number_visible': 'isSlideNumberVisible'
    }

    type_determiners = {
    }

    def __init__(self, self_uri=None, alternate_links=None, is_date_time_visible=None, date_time_text=None, is_footer_visible=None, footer_text=None, is_slide_number_visible=None):  # noqa: E501
        """HeaderFooter - a model defined in Swagger"""  # noqa: E501
        super(HeaderFooter, self).__init__(self_uri, alternate_links)

        self._is_date_time_visible = None
        self._date_time_text = None
        self._is_footer_visible = None
        self._footer_text = None
        self._is_slide_number_visible = None

        if is_date_time_visible is not None:
            self.is_date_time_visible = is_date_time_visible
        if date_time_text is not None:
            self.date_time_text = date_time_text
        if is_footer_visible is not None:
            self.is_footer_visible = is_footer_visible
        if footer_text is not None:
            self.footer_text = footer_text
        if is_slide_number_visible is not None:
            self.is_slide_number_visible = is_slide_number_visible

    @property
    def is_date_time_visible(self):
        """Gets the is_date_time_visible of this HeaderFooter.  # noqa: E501

        True if date is displayed in the footer  # noqa: E501

        :return: The is_date_time_visible of this HeaderFooter.  # noqa: E501
        :rtype: bool
        """
        return self._is_date_time_visible

    @is_date_time_visible.setter
    def is_date_time_visible(self, is_date_time_visible):
        """Sets the is_date_time_visible of this HeaderFooter.

        True if date is displayed in the footer  # noqa: E501

        :param is_date_time_visible: The is_date_time_visible of this HeaderFooter.  # noqa: E501
        :type: bool
        """
        self._is_date_time_visible = is_date_time_visible

    @property
    def date_time_text(self):
        """Gets the date_time_text of this HeaderFooter.  # noqa: E501

        Text to be displayed as date in the footer  # noqa: E501

        :return: The date_time_text of this HeaderFooter.  # noqa: E501
        :rtype: str
        """
        return self._date_time_text

    @date_time_text.setter
    def date_time_text(self, date_time_text):
        """Sets the date_time_text of this HeaderFooter.

        Text to be displayed as date in the footer  # noqa: E501

        :param date_time_text: The date_time_text of this HeaderFooter.  # noqa: E501
        :type: str
        """
        self._date_time_text = date_time_text

    @property
    def is_footer_visible(self):
        """Gets the is_footer_visible of this HeaderFooter.  # noqa: E501

        True if footer is displayed  # noqa: E501

        :return: The is_footer_visible of this HeaderFooter.  # noqa: E501
        :rtype: bool
        """
        return self._is_footer_visible

    @is_footer_visible.setter
    def is_footer_visible(self, is_footer_visible):
        """Sets the is_footer_visible of this HeaderFooter.

        True if footer is displayed  # noqa: E501

        :param is_footer_visible: The is_footer_visible of this HeaderFooter.  # noqa: E501
        :type: bool
        """
        self._is_footer_visible = is_footer_visible

    @property
    def footer_text(self):
        """Gets the footer_text of this HeaderFooter.  # noqa: E501

        Text to be displayed in the footer  # noqa: E501

        :return: The footer_text of this HeaderFooter.  # noqa: E501
        :rtype: str
        """
        return self._footer_text

    @footer_text.setter
    def footer_text(self, footer_text):
        """Sets the footer_text of this HeaderFooter.

        Text to be displayed in the footer  # noqa: E501

        :param footer_text: The footer_text of this HeaderFooter.  # noqa: E501
        :type: str
        """
        self._footer_text = footer_text

    @property
    def is_slide_number_visible(self):
        """Gets the is_slide_number_visible of this HeaderFooter.  # noqa: E501

        True if slide number is displayed in the footer  # noqa: E501

        :return: The is_slide_number_visible of this HeaderFooter.  # noqa: E501
        :rtype: bool
        """
        return self._is_slide_number_visible

    @is_slide_number_visible.setter
    def is_slide_number_visible(self, is_slide_number_visible):
        """Sets the is_slide_number_visible of this HeaderFooter.

        True if slide number is displayed in the footer  # noqa: E501

        :param is_slide_number_visible: The is_slide_number_visible of this HeaderFooter.  # noqa: E501
        :type: bool
        """
        self._is_slide_number_visible = is_slide_number_visible

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HeaderFooter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.math_element import MathElement

class ArrayElement(MathElement):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'arguments': 'list[MathElement]',
        'base_justification': 'str',
        'maximum_distribution': 'bool',
        'object_distribution': 'bool',
        'row_spacing_rule': 'str',
        'row_spacing': 'int'
    }

    attribute_map = {
        'type': 'type',
        'arguments': 'arguments',
        'base_justification': 'baseJustification',
        'maximum_distribution': 'maximumDistribution',
        'object_distribution': 'objectDistribution',
        'row_spacing_rule': 'rowSpacingRule',
        'row_spacing': 'rowSpacing'
    }

    type_determiners = {
        'type': 'Array',
    }

    def __init__(self, type='Array', arguments=None, base_justification=None, maximum_distribution=None, object_distribution=None, row_spacing_rule=None, row_spacing=None):  # noqa: E501
        """ArrayElement - a model defined in Swagger"""  # noqa: E501
        super(ArrayElement, self).__init__(type)

        self._arguments = None
        self._base_justification = None
        self._maximum_distribution = None
        self._object_distribution = None
        self._row_spacing_rule = None
        self._row_spacing = None
        self.type = 'Array'

        if arguments is not None:
            self.arguments = arguments
        if base_justification is not None:
            self.base_justification = base_justification
        if maximum_distribution is not None:
            self.maximum_distribution = maximum_distribution
        if object_distribution is not None:
            self.object_distribution = object_distribution
        if row_spacing_rule is not None:
            self.row_spacing_rule = row_spacing_rule
        if row_spacing is not None:
            self.row_spacing = row_spacing

    @property
    def arguments(self):
        """Gets the arguments of this ArrayElement.  # noqa: E501

        Arguments  # noqa: E501

        :return: The arguments of this ArrayElement.  # noqa: E501
        :rtype: list[MathElement]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this ArrayElement.

        Arguments  # noqa: E501

        :param arguments: The arguments of this ArrayElement.  # noqa: E501
        :type: list[MathElement]
        """
        self._arguments = arguments

    @property
    def base_justification(self):
        """Gets the base_justification of this ArrayElement.  # noqa: E501

        Specifies alignment of the array relative to surrounding text  # noqa: E501

        :return: The base_justification of this ArrayElement.  # noqa: E501
        :rtype: str
        """
        return self._base_justification

    @base_justification.setter
    def base_justification(self, base_justification):
        """Sets the base_justification of this ArrayElement.

        Specifies alignment of the array relative to surrounding text  # noqa: E501

        :param base_justification: The base_justification of this ArrayElement.  # noqa: E501
        :type: str
        """
        if base_justification is not None:
            allowed_values = ["NotDefined", "Top", "Center", "Bottom"]  # noqa: E501
            if base_justification.isdigit():
                int_base_justification = int(base_justification)
                if int_base_justification < 0 or int_base_justification >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `base_justification` ({0}), must be one of {1}"  # noqa: E501
                        .format(base_justification, allowed_values)
                    )
                self._base_justification = allowed_values[int_base_justification]
                return
            if base_justification not in allowed_values:
                raise ValueError(
                    "Invalid value for `base_justification` ({0}), must be one of {1}"  # noqa: E501
                    .format(base_justification, allowed_values)
                )
        self._base_justification = base_justification

    @property
    def maximum_distribution(self):
        """Gets the maximum_distribution of this ArrayElement.  # noqa: E501

        Maximum Distribution  # noqa: E501

        :return: The maximum_distribution of this ArrayElement.  # noqa: E501
        :rtype: bool
        """
        return self._maximum_distribution

    @maximum_distribution.setter
    def maximum_distribution(self, maximum_distribution):
        """Sets the maximum_distribution of this ArrayElement.

        Maximum Distribution  # noqa: E501

        :param maximum_distribution: The maximum_distribution of this ArrayElement.  # noqa: E501
        :type: bool
        """
        self._maximum_distribution = maximum_distribution

    @property
    def object_distribution(self):
        """Gets the object_distribution of this ArrayElement.  # noqa: E501

        Object Distribution  # noqa: E501

        :return: The object_distribution of this ArrayElement.  # noqa: E501
        :rtype: bool
        """
        return self._object_distribution

    @object_distribution.setter
    def object_distribution(self, object_distribution):
        """Sets the object_distribution of this ArrayElement.

        Object Distribution  # noqa: E501

        :param object_distribution: The object_distribution of this ArrayElement.  # noqa: E501
        :type: bool
        """
        self._object_distribution = object_distribution

    @property
    def row_spacing_rule(self):
        """Gets the row_spacing_rule of this ArrayElement.  # noqa: E501

        The type of vertical spacing between array elements  # noqa: E501

        :return: The row_spacing_rule of this ArrayElement.  # noqa: E501
        :rtype: str
        """
        return self._row_spacing_rule

    @row_spacing_rule.setter
    def row_spacing_rule(self, row_spacing_rule):
        """Sets the row_spacing_rule of this ArrayElement.

        The type of vertical spacing between array elements  # noqa: E501

        :param row_spacing_rule: The row_spacing_rule of this ArrayElement.  # noqa: E501
        :type: str
        """
        if row_spacing_rule is not None:
            allowed_values = ["SingleLineGap", "OneAndAHalfLineGap", "TwoLineGap", "Exactly", "Multiple"]  # noqa: E501
            if row_spacing_rule.isdigit():
                int_row_spacing_rule = int(row_spacing_rule)
                if int_row_spacing_rule < 0 or int_row_spacing_rule >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `row_spacing_rule` ({0}), must be one of {1}"  # noqa: E501
                        .format(row_spacing_rule, allowed_values)
                    )
                self._row_spacing_rule = allowed_values[int_row_spacing_rule]
                return
            if row_spacing_rule not in allowed_values:
                raise ValueError(
                    "Invalid value for `row_spacing_rule` ({0}), must be one of {1}"  # noqa: E501
                    .format(row_spacing_rule, allowed_values)
                )
        self._row_spacing_rule = row_spacing_rule

    @property
    def row_spacing(self):
        """Gets the row_spacing of this ArrayElement.  # noqa: E501

        Spacing between rows of an array  # noqa: E501

        :return: The row_spacing of this ArrayElement.  # noqa: E501
        :rtype: int
        """
        return self._row_spacing

    @row_spacing.setter
    def row_spacing(self, row_spacing):
        """Sets the row_spacing of this ArrayElement.

        Spacing between rows of an array  # noqa: E501

        :param row_spacing: The row_spacing of this ArrayElement.  # noqa: E501
        :type: int
        """
        self._row_spacing = row_spacing

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArrayElement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.export_options import ExportOptions

class VideoExportOptions(ExportOptions):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'default_regular_font': 'str',
        'font_fallback_rules': 'list[FontFallbackRule]',
        'format': 'str',
        'slides_transition_duration': 'int',
        'transition_type': 'str',
        'transition_duration': 'int',
        'video_resolution_type': 'str'
    }

    attribute_map = {
        'default_regular_font': 'defaultRegularFont',
        'font_fallback_rules': 'fontFallbackRules',
        'format': 'format',
        'slides_transition_duration': 'slidesTransitionDuration',
        'transition_type': 'transitionType',
        'transition_duration': 'transitionDuration',
        'video_resolution_type': 'videoResolutionType'
    }

    type_determiners = {
        'format': 'mpeg4',
    }

    def __init__(self, default_regular_font=None, font_fallback_rules=None, format='mpeg4', slides_transition_duration=None, transition_type=None, transition_duration=None, video_resolution_type=None):  # noqa: E501
        """VideoExportOptions - a model defined in Swagger"""  # noqa: E501
        super(VideoExportOptions, self).__init__(default_regular_font, font_fallback_rules, format)

        self._slides_transition_duration = None
        self._transition_type = None
        self._transition_duration = None
        self._video_resolution_type = None
        self.format = 'mpeg4'

        if slides_transition_duration is not None:
            self.slides_transition_duration = slides_transition_duration
        if transition_type is not None:
            self.transition_type = transition_type
        if transition_duration is not None:
            self.transition_duration = transition_duration
        if video_resolution_type is not None:
            self.video_resolution_type = video_resolution_type

    @property
    def slides_transition_duration(self):
        """Gets the slides_transition_duration of this VideoExportOptions.  # noqa: E501

        Slides transition duration.  # noqa: E501

        :return: The slides_transition_duration of this VideoExportOptions.  # noqa: E501
        :rtype: int
        """
        return self._slides_transition_duration

    @slides_transition_duration.setter
    def slides_transition_duration(self, slides_transition_duration):
        """Sets the slides_transition_duration of this VideoExportOptions.

        Slides transition duration.  # noqa: E501

        :param slides_transition_duration: The slides_transition_duration of this VideoExportOptions.  # noqa: E501
        :type: int
        """
        self._slides_transition_duration = slides_transition_duration

    @property
    def transition_type(self):
        """Gets the transition_type of this VideoExportOptions.  # noqa: E501

        Video transition type  # noqa: E501

        :return: The transition_type of this VideoExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._transition_type

    @transition_type.setter
    def transition_type(self, transition_type):
        """Sets the transition_type of this VideoExportOptions.

        Video transition type  # noqa: E501

        :param transition_type: The transition_type of this VideoExportOptions.  # noqa: E501
        :type: str
        """
        if transition_type is not None:
            allowed_values = ["None", "Fade", "Distance", "Slidedown", "Slideright", "Slideleft", "Slideup", "Smoothleft", "Smoothright", "Smoothup", "Smoothdown", "Rectcrop", "Circlecrop", "Circleclose", "Circleopen", "Horzclose", "Horzopen", "Vertclose", "Vertopen", "Diagbl", "Diagbr", "Diagtl", "Diagtr", "Hlslice", "Hrslice", "Vuslice", "Vdslice", "Dissolve", "Pixelize", "Radial"]  # noqa: E501
            if transition_type.isdigit():
                int_transition_type = int(transition_type)
                if int_transition_type < 0 or int_transition_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `transition_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(transition_type, allowed_values)
                    )
                self._transition_type = allowed_values[int_transition_type]
                return
            if transition_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `transition_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(transition_type, allowed_values)
                )
        self._transition_type = transition_type

    @property
    def transition_duration(self):
        """Gets the transition_duration of this VideoExportOptions.  # noqa: E501

        Duration of transition defined in TransitionType property.  # noqa: E501

        :return: The transition_duration of this VideoExportOptions.  # noqa: E501
        :rtype: int
        """
        return self._transition_duration

    @transition_duration.setter
    def transition_duration(self, transition_duration):
        """Sets the transition_duration of this VideoExportOptions.

        Duration of transition defined in TransitionType property.  # noqa: E501

        :param transition_duration: The transition_duration of this VideoExportOptions.  # noqa: E501
        :type: int
        """
        self._transition_duration = transition_duration

    @property
    def video_resolution_type(self):
        """Gets the video_resolution_type of this VideoExportOptions.  # noqa: E501

        Video resolution type  # noqa: E501

        :return: The video_resolution_type of this VideoExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._video_resolution_type

    @video_resolution_type.setter
    def video_resolution_type(self, video_resolution_type):
        """Sets the video_resolution_type of this VideoExportOptions.

        Video resolution type  # noqa: E501

        :param video_resolution_type: The video_resolution_type of this VideoExportOptions.  # noqa: E501
        :type: str
        """
        if video_resolution_type is not None:
            allowed_values = ["FullHD", "SD", "HD", "QHD"]  # noqa: E501
            if video_resolution_type.isdigit():
                int_video_resolution_type = int(video_resolution_type)
                if int_video_resolution_type < 0 or int_video_resolution_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `video_resolution_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(video_resolution_type, allowed_values)
                    )
                self._video_resolution_type = allowed_values[int_video_resolution_type]
                return
            if video_resolution_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `video_resolution_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(video_resolution_type, allowed_values)
                )
        self._video_resolution_type = video_resolution_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoExportOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class Camera(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'camera_type': 'str',
        'field_of_view_angle': 'float',
        'zoom': 'float',
        'x_rotation': 'float',
        'y_rotation': 'float',
        'z_rotation': 'float'
    }

    attribute_map = {
        'camera_type': 'cameraType',
        'field_of_view_angle': 'fieldOfViewAngle',
        'zoom': 'zoom',
        'x_rotation': 'xRotation',
        'y_rotation': 'yRotation',
        'z_rotation': 'zRotation'
    }

    type_determiners = {
    }

    def __init__(self, camera_type=None, field_of_view_angle=None, zoom=None, x_rotation=None, y_rotation=None, z_rotation=None):  # noqa: E501
        """Camera - a model defined in Swagger"""  # noqa: E501

        self._camera_type = None
        self._field_of_view_angle = None
        self._zoom = None
        self._x_rotation = None
        self._y_rotation = None
        self._z_rotation = None

        if camera_type is not None:
            self.camera_type = camera_type
        if field_of_view_angle is not None:
            self.field_of_view_angle = field_of_view_angle
        if zoom is not None:
            self.zoom = zoom
        if x_rotation is not None:
            self.x_rotation = x_rotation
        if y_rotation is not None:
            self.y_rotation = y_rotation
        if z_rotation is not None:
            self.z_rotation = z_rotation

    @property
    def camera_type(self):
        """Gets the camera_type of this Camera.  # noqa: E501

        Camera type  # noqa: E501

        :return: The camera_type of this Camera.  # noqa: E501
        :rtype: str
        """
        return self._camera_type

    @camera_type.setter
    def camera_type(self, camera_type):
        """Sets the camera_type of this Camera.

        Camera type  # noqa: E501

        :param camera_type: The camera_type of this Camera.  # noqa: E501
        :type: str
        """
        if camera_type is not None:
            allowed_values = ["IsometricBottomDown", "IsometricBottomUp", "IsometricLeftDown", "IsometricLeftUp", "IsometricOffAxis1Left", "IsometricOffAxis1Right", "IsometricOffAxis1Top", "IsometricOffAxis2Left", "IsometricOffAxis2Right", "IsometricOffAxis2Top", "IsometricOffAxis3Bottom", "IsometricOffAxis3Left", "IsometricOffAxis3Right", "IsometricOffAxis4Bottom", "IsometricOffAxis4Left", "IsometricOffAxis4Right", "IsometricRightDown", "IsometricRightUp", "IsometricTopDown", "IsometricTopUp", "LegacyObliqueBottom", "LegacyObliqueBottomLeft", "LegacyObliqueBottomRight", "LegacyObliqueFront", "LegacyObliqueLeft", "LegacyObliqueRight", "LegacyObliqueTop", "LegacyObliqueTopLeft", "LegacyObliqueTopRight", "LegacyPerspectiveBottom", "LegacyPerspectiveBottomLeft", "LegacyPerspectiveBottomRight", "LegacyPerspectiveFront", "LegacyPerspectiveLeft", "LegacyPerspectiveRight", "LegacyPerspectiveTop", "LegacyPerspectiveTopLeft", "LegacyPerspectiveTopRight", "ObliqueBottom", "ObliqueBottomLeft", "ObliqueBottomRight", "ObliqueLeft", "ObliqueRight", "ObliqueTop", "ObliqueTopLeft", "ObliqueTopRight", "OrthographicFront", "PerspectiveAbove", "PerspectiveAboveLeftFacing", "PerspectiveAboveRightFacing", "PerspectiveBelow", "PerspectiveContrastingLeftFacing", "PerspectiveContrastingRightFacing", "PerspectiveFront", "PerspectiveHeroicExtremeLeftFacing", "PerspectiveHeroicExtremeRightFacing", "PerspectiveHeroicLeftFacing", "PerspectiveHeroicRightFacing", "PerspectiveLeft", "PerspectiveRelaxed", "PerspectiveRelaxedModerately", "PerspectiveRight", "NotDefined"]  # noqa: E501
            if camera_type.isdigit():
                int_camera_type = int(camera_type)
                if int_camera_type < 0 or int_camera_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `camera_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(camera_type, allowed_values)
                    )
                self._camera_type = allowed_values[int_camera_type]
                return
            if camera_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `camera_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(camera_type, allowed_values)
                )
        self._camera_type = camera_type

    @property
    def field_of_view_angle(self):
        """Gets the field_of_view_angle of this Camera.  # noqa: E501

        Camera FOV  # noqa: E501

        :return: The field_of_view_angle of this Camera.  # noqa: E501
        :rtype: float
        """
        return self._field_of_view_angle

    @field_of_view_angle.setter
    def field_of_view_angle(self, field_of_view_angle):
        """Sets the field_of_view_angle of this Camera.

        Camera FOV  # noqa: E501

        :param field_of_view_angle: The field_of_view_angle of this Camera.  # noqa: E501
        :type: float
        """
        self._field_of_view_angle = field_of_view_angle

    @property
    def zoom(self):
        """Gets the zoom of this Camera.  # noqa: E501

        Camera zoom  # noqa: E501

        :return: The zoom of this Camera.  # noqa: E501
        :rtype: float
        """
        return self._zoom

    @zoom.setter
    def zoom(self, zoom):
        """Sets the zoom of this Camera.

        Camera zoom  # noqa: E501

        :param zoom: The zoom of this Camera.  # noqa: E501
        :type: float
        """
        self._zoom = zoom

    @property
    def x_rotation(self):
        """Gets the x_rotation of this Camera.  # noqa: E501

        XRotation  # noqa: E501

        :return: The x_rotation of this Camera.  # noqa: E501
        :rtype: float
        """
        return self._x_rotation

    @x_rotation.setter
    def x_rotation(self, x_rotation):
        """Sets the x_rotation of this Camera.

        XRotation  # noqa: E501

        :param x_rotation: The x_rotation of this Camera.  # noqa: E501
        :type: float
        """
        self._x_rotation = x_rotation

    @property
    def y_rotation(self):
        """Gets the y_rotation of this Camera.  # noqa: E501

        YRotation  # noqa: E501

        :return: The y_rotation of this Camera.  # noqa: E501
        :rtype: float
        """
        return self._y_rotation

    @y_rotation.setter
    def y_rotation(self, y_rotation):
        """Sets the y_rotation of this Camera.

        YRotation  # noqa: E501

        :param y_rotation: The y_rotation of this Camera.  # noqa: E501
        :type: float
        """
        self._y_rotation = y_rotation

    @property
    def z_rotation(self):
        """Gets the z_rotation of this Camera.  # noqa: E501

        ZRotation  # noqa: E501

        :return: The z_rotation of this Camera.  # noqa: E501
        :rtype: float
        """
        return self._z_rotation

    @z_rotation.setter
    def z_rotation(self, z_rotation):
        """Sets the z_rotation of this Camera.

        ZRotation  # noqa: E501

        :param z_rotation: The z_rotation of this Camera.  # noqa: E501
        :type: float
        """
        self._z_rotation = z_rotation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Camera):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.resource_base import ResourceBase

class SlideProperties(ResourceBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'first_slide_number': 'int',
        'orientation': 'str',
        'scale_type': 'str',
        'size_type': 'str',
        'width': 'int',
        'height': 'int'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'first_slide_number': 'firstSlideNumber',
        'orientation': 'orientation',
        'scale_type': 'scaleType',
        'size_type': 'sizeType',
        'width': 'width',
        'height': 'height'
    }

    type_determiners = {
    }

    def __init__(self, self_uri=None, alternate_links=None, first_slide_number=None, orientation=None, scale_type=None, size_type=None, width=None, height=None):  # noqa: E501
        """SlideProperties - a model defined in Swagger"""  # noqa: E501
        super(SlideProperties, self).__init__(self_uri, alternate_links)

        self._first_slide_number = None
        self._orientation = None
        self._scale_type = None
        self._size_type = None
        self._width = None
        self._height = None

        if first_slide_number is not None:
            self.first_slide_number = first_slide_number
        if orientation is not None:
            self.orientation = orientation
        if scale_type is not None:
            self.scale_type = scale_type
        if size_type is not None:
            self.size_type = size_type
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height

    @property
    def first_slide_number(self):
        """Gets the first_slide_number of this SlideProperties.  # noqa: E501

        First slide number.  # noqa: E501

        :return: The first_slide_number of this SlideProperties.  # noqa: E501
        :rtype: int
        """
        return self._first_slide_number

    @first_slide_number.setter
    def first_slide_number(self, first_slide_number):
        """Sets the first_slide_number of this SlideProperties.

        First slide number.  # noqa: E501

        :param first_slide_number: The first_slide_number of this SlideProperties.  # noqa: E501
        :type: int
        """
        self._first_slide_number = first_slide_number

    @property
    def orientation(self):
        """Gets the orientation of this SlideProperties.  # noqa: E501

        Slide orientation.  # noqa: E501

        :return: The orientation of this SlideProperties.  # noqa: E501
        :rtype: str
        """
        return self._orientation

    @orientation.setter
    def orientation(self, orientation):
        """Sets the orientation of this SlideProperties.

        Slide orientation.  # noqa: E501

        :param orientation: The orientation of this SlideProperties.  # noqa: E501
        :type: str
        """
        if orientation is not None:
            allowed_values = ["Landscape", "Portrait"]  # noqa: E501
            if orientation.isdigit():
                int_orientation = int(orientation)
                if int_orientation < 0 or int_orientation >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `orientation` ({0}), must be one of {1}"  # noqa: E501
                        .format(orientation, allowed_values)
                    )
                self._orientation = allowed_values[int_orientation]
                return
            if orientation not in allowed_values:
                raise ValueError(
                    "Invalid value for `orientation` ({0}), must be one of {1}"  # noqa: E501
                    .format(orientation, allowed_values)
                )
        self._orientation = orientation

    @property
    def scale_type(self):
        """Gets the scale_type of this SlideProperties.  # noqa: E501

        Scale type.  # noqa: E501

        :return: The scale_type of this SlideProperties.  # noqa: E501
        :rtype: str
        """
        return self._scale_type

    @scale_type.setter
    def scale_type(self, scale_type):
        """Sets the scale_type of this SlideProperties.

        Scale type.  # noqa: E501

        :param scale_type: The scale_type of this SlideProperties.  # noqa: E501
        :type: str
        """
        if scale_type is not None:
            allowed_values = ["DoNotScale", "EnsureFit", "Maximize"]  # noqa: E501
            if scale_type.isdigit():
                int_scale_type = int(scale_type)
                if int_scale_type < 0 or int_scale_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `scale_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(scale_type, allowed_values)
                    )
                self._scale_type = allowed_values[int_scale_type]
                return
            if scale_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `scale_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(scale_type, allowed_values)
                )
        self._scale_type = scale_type

    @property
    def size_type(self):
        """Gets the size_type of this SlideProperties.  # noqa: E501

        Size type.  # noqa: E501

        :return: The size_type of this SlideProperties.  # noqa: E501
        :rtype: str
        """
        return self._size_type

    @size_type.setter
    def size_type(self, size_type):
        """Sets the size_type of this SlideProperties.

        Size type.  # noqa: E501

        :param size_type: The size_type of this SlideProperties.  # noqa: E501
        :type: str
        """
        if size_type is not None:
            allowed_values = ["OnScreen", "LetterPaper", "A4Paper", "Slide35mm", "Overhead", "Banner", "Custom", "Ledger", "A3Paper", "B4IsoPaper", "B5IsoPaper", "B4JisPaper", "B5JisPaper", "HagakiCard", "OnScreen16x9", "OnScreen16x10", "Widescreen"]  # noqa: E501
            if size_type.isdigit():
                int_size_type = int(size_type)
                if int_size_type < 0 or int_size_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `size_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(size_type, allowed_values)
                    )
                self._size_type = allowed_values[int_size_type]
                return
            if size_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `size_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(size_type, allowed_values)
                )
        self._size_type = size_type

    @property
    def width(self):
        """Gets the width of this SlideProperties.  # noqa: E501

        Width.  # noqa: E501

        :return: The width of this SlideProperties.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this SlideProperties.

        Width.  # noqa: E501

        :param width: The width of this SlideProperties.  # noqa: E501
        :type: int
        """
        self._width = width

    @property
    def height(self):
        """Gets the height of this SlideProperties.  # noqa: E501

        Height.  # noqa: E501

        :return: The height of this SlideProperties.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this SlideProperties.

        Height.  # noqa: E501

        :param height: The height of this SlideProperties.  # noqa: E501
        :type: int
        """
        self._height = height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SlideProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.math_element import MathElement

class MatrixElement(MathElement):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'hide_placeholders': 'bool',
        'base_justification': 'str',
        'min_column_width': 'int',
        'column_gap_rule': 'str',
        'column_gap': 'int',
        'row_gap_rule': 'str',
        'row_gap': 'int',
        'items': 'list[list[MathElement]]'
    }

    attribute_map = {
        'type': 'type',
        'hide_placeholders': 'hidePlaceholders',
        'base_justification': 'baseJustification',
        'min_column_width': 'minColumnWidth',
        'column_gap_rule': 'columnGapRule',
        'column_gap': 'columnGap',
        'row_gap_rule': 'rowGapRule',
        'row_gap': 'rowGap',
        'items': 'items'
    }

    type_determiners = {
        'type': 'Matrix',
    }

    def __init__(self, type='Matrix', hide_placeholders=None, base_justification=None, min_column_width=None, column_gap_rule=None, column_gap=None, row_gap_rule=None, row_gap=None, items=None):  # noqa: E501
        """MatrixElement - a model defined in Swagger"""  # noqa: E501
        super(MatrixElement, self).__init__(type)

        self._hide_placeholders = None
        self._base_justification = None
        self._min_column_width = None
        self._column_gap_rule = None
        self._column_gap = None
        self._row_gap_rule = None
        self._row_gap = None
        self._items = None
        self.type = 'Matrix'

        if hide_placeholders is not None:
            self.hide_placeholders = hide_placeholders
        if base_justification is not None:
            self.base_justification = base_justification
        if min_column_width is not None:
            self.min_column_width = min_column_width
        if column_gap_rule is not None:
            self.column_gap_rule = column_gap_rule
        if column_gap is not None:
            self.column_gap = column_gap
        if row_gap_rule is not None:
            self.row_gap_rule = row_gap_rule
        if row_gap is not None:
            self.row_gap = row_gap
        if items is not None:
            self.items = items

    @property
    def hide_placeholders(self):
        """Gets the hide_placeholders of this MatrixElement.  # noqa: E501

        Hide the placeholders for empty matrix elements  # noqa: E501

        :return: The hide_placeholders of this MatrixElement.  # noqa: E501
        :rtype: bool
        """
        return self._hide_placeholders

    @hide_placeholders.setter
    def hide_placeholders(self, hide_placeholders):
        """Sets the hide_placeholders of this MatrixElement.

        Hide the placeholders for empty matrix elements  # noqa: E501

        :param hide_placeholders: The hide_placeholders of this MatrixElement.  # noqa: E501
        :type: bool
        """
        self._hide_placeholders = hide_placeholders

    @property
    def base_justification(self):
        """Gets the base_justification of this MatrixElement.  # noqa: E501

        Specifies the vertical justification respect to surrounding text.   # noqa: E501

        :return: The base_justification of this MatrixElement.  # noqa: E501
        :rtype: str
        """
        return self._base_justification

    @base_justification.setter
    def base_justification(self, base_justification):
        """Sets the base_justification of this MatrixElement.

        Specifies the vertical justification respect to surrounding text.   # noqa: E501

        :param base_justification: The base_justification of this MatrixElement.  # noqa: E501
        :type: str
        """
        if base_justification is not None:
            allowed_values = ["NotDefined", "Top", "Center", "Bottom"]  # noqa: E501
            if base_justification.isdigit():
                int_base_justification = int(base_justification)
                if int_base_justification < 0 or int_base_justification >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `base_justification` ({0}), must be one of {1}"  # noqa: E501
                        .format(base_justification, allowed_values)
                    )
                self._base_justification = allowed_values[int_base_justification]
                return
            if base_justification not in allowed_values:
                raise ValueError(
                    "Invalid value for `base_justification` ({0}), must be one of {1}"  # noqa: E501
                    .format(base_justification, allowed_values)
                )
        self._base_justification = base_justification

    @property
    def min_column_width(self):
        """Gets the min_column_width of this MatrixElement.  # noqa: E501

        Minimum column width in twips (1/20th of a point)  # noqa: E501

        :return: The min_column_width of this MatrixElement.  # noqa: E501
        :rtype: int
        """
        return self._min_column_width

    @min_column_width.setter
    def min_column_width(self, min_column_width):
        """Sets the min_column_width of this MatrixElement.

        Minimum column width in twips (1/20th of a point)  # noqa: E501

        :param min_column_width: The min_column_width of this MatrixElement.  # noqa: E501
        :type: int
        """
        self._min_column_width = min_column_width

    @property
    def column_gap_rule(self):
        """Gets the column_gap_rule of this MatrixElement.  # noqa: E501

        The type of horizontal spacing between columns of a matrix.  # noqa: E501

        :return: The column_gap_rule of this MatrixElement.  # noqa: E501
        :rtype: str
        """
        return self._column_gap_rule

    @column_gap_rule.setter
    def column_gap_rule(self, column_gap_rule):
        """Sets the column_gap_rule of this MatrixElement.

        The type of horizontal spacing between columns of a matrix.  # noqa: E501

        :param column_gap_rule: The column_gap_rule of this MatrixElement.  # noqa: E501
        :type: str
        """
        if column_gap_rule is not None:
            allowed_values = ["SingleSpacingGap", "OneAndHalfSpacingGap", "DoubleSpacingGap", "Exactly", "Multiple"]  # noqa: E501
            if column_gap_rule.isdigit():
                int_column_gap_rule = int(column_gap_rule)
                if int_column_gap_rule < 0 or int_column_gap_rule >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `column_gap_rule` ({0}), must be one of {1}"  # noqa: E501
                        .format(column_gap_rule, allowed_values)
                    )
                self._column_gap_rule = allowed_values[int_column_gap_rule]
                return
            if column_gap_rule not in allowed_values:
                raise ValueError(
                    "Invalid value for `column_gap_rule` ({0}), must be one of {1}"  # noqa: E501
                    .format(column_gap_rule, allowed_values)
                )
        self._column_gap_rule = column_gap_rule

    @property
    def column_gap(self):
        """Gets the column_gap of this MatrixElement.  # noqa: E501

        The value of horizontal spacing between columns of a matrix  # noqa: E501

        :return: The column_gap of this MatrixElement.  # noqa: E501
        :rtype: int
        """
        return self._column_gap

    @column_gap.setter
    def column_gap(self, column_gap):
        """Sets the column_gap of this MatrixElement.

        The value of horizontal spacing between columns of a matrix  # noqa: E501

        :param column_gap: The column_gap of this MatrixElement.  # noqa: E501
        :type: int
        """
        self._column_gap = column_gap

    @property
    def row_gap_rule(self):
        """Gets the row_gap_rule of this MatrixElement.  # noqa: E501

        The type of vertical spacing between rows of a matrix  # noqa: E501

        :return: The row_gap_rule of this MatrixElement.  # noqa: E501
        :rtype: str
        """
        return self._row_gap_rule

    @row_gap_rule.setter
    def row_gap_rule(self, row_gap_rule):
        """Sets the row_gap_rule of this MatrixElement.

        The type of vertical spacing between rows of a matrix  # noqa: E501

        :param row_gap_rule: The row_gap_rule of this MatrixElement.  # noqa: E501
        :type: str
        """
        if row_gap_rule is not None:
            allowed_values = ["SingleSpacingGap", "OneAndHalfSpacingGap", "DoubleSpacingGap", "Exactly", "Multiple"]  # noqa: E501
            if row_gap_rule.isdigit():
                int_row_gap_rule = int(row_gap_rule)
                if int_row_gap_rule < 0 or int_row_gap_rule >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `row_gap_rule` ({0}), must be one of {1}"  # noqa: E501
                        .format(row_gap_rule, allowed_values)
                    )
                self._row_gap_rule = allowed_values[int_row_gap_rule]
                return
            if row_gap_rule not in allowed_values:
                raise ValueError(
                    "Invalid value for `row_gap_rule` ({0}), must be one of {1}"  # noqa: E501
                    .format(row_gap_rule, allowed_values)
                )
        self._row_gap_rule = row_gap_rule

    @property
    def row_gap(self):
        """Gets the row_gap of this MatrixElement.  # noqa: E501

        The value of vertical spacing between rows of a matrix;               # noqa: E501

        :return: The row_gap of this MatrixElement.  # noqa: E501
        :rtype: int
        """
        return self._row_gap

    @row_gap.setter
    def row_gap(self, row_gap):
        """Sets the row_gap of this MatrixElement.

        The value of vertical spacing between rows of a matrix;               # noqa: E501

        :param row_gap: The row_gap of this MatrixElement.  # noqa: E501
        :type: int
        """
        self._row_gap = row_gap

    @property
    def items(self):
        """Gets the items of this MatrixElement.  # noqa: E501

        Matrix items  # noqa: E501

        :return: The items of this MatrixElement.  # noqa: E501
        :rtype: list[list[MathElement]]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this MatrixElement.

        Matrix items  # noqa: E501

        :param items: The items of this MatrixElement.  # noqa: E501
        :type: list[list[MathElement]]
        """
        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MatrixElement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
